@@ -10,36 +10,40 @@ use teloxide::prelude::*;
 use teloxide::types::{
     InlineKeyboardButton, InlineKeyboardButtonKind, InlineKeyboardMarkup,
 };
+use teloxide::RequestError;
 use tg::TgResponse;
 
 pub async fn start(bot: &Bot, user_id: i64) -> Result<(), RequestError> {
     tg::send_message(&TgResponse::Hello.to_string(), bot, user_id).await
 }
 
-/// Send a list of all notifications
-pub async fn list(bot: &Bot, user_id: i64) -> Result<(), RequestError> {
-    let reminders_future = db::get_pending_user_reminders(user_id).map(|v| {
+fn get_sorted_reminders(
+    user_id: i64,
+) -> Result<std::vec::IntoIter<Box<dyn tg::GenericReminder>>, rusqlite::Error> {
+    let reminders_future = db::get_pending_user_reminders(user_id);
+    let cron_reminders_future = db::get_pending_user_cron_reminders(user_id);
+    let gen_rems = reminders_future.map(|v| {
         v.into_iter()
             .map::<Box<dyn tg::GenericReminder>, _>(|x| Box::new(x))
     });
-    let cron_reminders_future = db::get_pending_user_cron_reminders(user_id)
-        .map(|v| {
-            v.into_iter()
-                .map::<Box<dyn tg::GenericReminder>, _>(|x| Box::new(x))
-        });
-    // Merge one-time and periodic reminders
-    let all_reminders = reminders_future.and_then(|rems| {
-        cron_reminders_future.map(|cron_rems| rems.chain(cron_rems))
+    let gen_cron_rems = cron_reminders_future.map(|v| {
+        v.into_iter()
+            .map::<Box<dyn tg::GenericReminder>, _>(|x| Box::new(x))
     });
-    // Sort all reminders ascending of their time appearance
-    let sorted_reminders =
-        all_reminders.map(|rems| rems.sorted().map(|x| x.to_string()));
+    gen_rems
+        .and_then(|rems| gen_cron_rems.map(|cron_rems| rems.chain(cron_rems)))
+        .map(|rems| rems.sorted())
+}
+
+/// Send a list of all notifications
+pub async fn list(bot: &Bot, user_id: i64) -> Result<(), RequestError> {
+    let sorted_reminders = get_sorted_reminders(user_id);
     // Format reminders
     let text = sorted_reminders
         .map(|rems| {
             vec![TgResponse::RemindersListHeader.to_string()]
                 .into_iter()
-                .chain(rems)
+                .chain(rems.map(|rem| rem.to_string()))
                 .collect::<Vec<String>>()
                 .join("\n")
         })
@@ -122,7 +126,7 @@ pub async fn set_reminder(
     text: &str,
     bot: &Bot,
     user_id: i64,
-    from_id_opt: Option<i32>,
+    from_id_opt: Option<i64>,
     silent_success: bool,
 ) -> Result<bool, RequestError> {
     if let Some(reminder) = tg::parse_req(text, user_id) {
@@ -178,10 +182,7 @@ pub async fn set_reminder(
         };
         tg::send_message(&response.to_string(), bot, user_id).await?;
         Ok(ok)
-    } else if from_id_opt
-        .filter(|&from_id| from_id as i64 == user_id)
-        .is_some()
-    {
+    } else if from_id_opt.filter(|&from_id| from_id == user_id).is_some() {
         let response = if tz::get_user_timezone(user_id).is_err() {
             TgResponse::NoChosenTimezone
         } else {
@@ -367,7 +368,7 @@ pub async fn replace_reminder(
     bot: &Bot,
     user_id: i64,
     rem_id: u32,
-    from_id_opt: Option<i32>,
+    from_id_opt: Option<i64>,
 ) -> Result<(), RequestError> {
     if set_reminder(text, bot, user_id, from_id_opt, true).await? {
         let response = match db::mark_reminder_as_sent(rem_id) {
@@ -389,7 +390,7 @@ pub async fn replace_cron_reminder(
     bot: &Bot,
     user_id: i64,
     rem_id: u32,
-    from_id_opt: Option<i32>,
+    from_id_opt: Option<i64>,
 ) -> Result<(), RequestError> {
     if set_reminder(text, bot, user_id, from_id_opt, true).await? {
         let response = match db::mark_cron_reminder_as_sent(rem_id) {
@@ -423,7 +424,7 @@ pub fn get_markup_for_tz_page_idx(num: usize) -> InlineKeyboardMarkup {
                             ),
                         )
                     })
-                    .collect(),
+                    .collect::<Vec<_>>(),
             );
         }
     } else {
@@ -456,8 +457,9 @@ fn get_markup_for_reminders_page_alteration(
 ) -> InlineKeyboardMarkup {
     let mut markup = InlineKeyboardMarkup::default();
     let mut last_rem_page: bool = false;
-    let mut last_cron_rem_page: bool = false;
-    if let Some(reminders) = db::get_pending_user_reminders(user_id)
+    let sorted_reminders =
+        get_sorted_reminders(user_id).map(|rems| rems.collect::<Vec<_>>());
+    if let Some(reminders) = sorted_reminders
         .ok()
         .as_ref()
         .and_then(|rems| rems.chunks(45).into_iter().nth(num))
@@ -465,50 +467,23 @@ fn get_markup_for_reminders_page_alteration(
         for chunk in reminders.chunks(1) {
             markup = markup.append_row(
                 chunk
-                    .to_vec()
-                    .into_iter()
+                    .iter()
                     .map(|rem| {
                         InlineKeyboardButton::new(
                             rem.to_unescaped_string(),
                             InlineKeyboardButtonKind::CallbackData(
                                 cb_prefix.to_owned()
                                     + "::alt::"
-                                    + &rem.id.to_string(),
+                                    + &rem.get_id().to_string(),
                             ),
                         )
                     })
-                    .collect(),
+                    .collect::<Vec<_>>(),
             );
         }
     } else {
         last_rem_page = true;
     }
-    if let Some(cron_reminders) = db::get_pending_user_cron_reminders(user_id)
-        .ok()
-        .as_ref()
-        .and_then(|cron_rems| cron_rems.chunks(45).into_iter().nth(num))
-    {
-        for chunk in cron_reminders.chunks(1) {
-            markup = markup.append_row(
-                chunk
-                    .to_vec()
-                    .into_iter()
-                    .map(|cron_rem| {
-                        InlineKeyboardButton::new(
-                            cron_rem.to_unescaped_string(),
-                            InlineKeyboardButtonKind::CallbackData(
-                                cb_prefix.to_owned()
-                                    + "::cron_alt::"
-                                    + &cron_rem.id.to_string(),
-                            ),
-                        )
-                    })
-                    .collect(),
-            );
-        }
-    } else {
-        last_cron_rem_page = true;
-    }
     let mut move_buttons = vec![];
     if num > 0 {
         move_buttons.push(InlineKeyboardButton::new(
@@ -518,7 +493,7 @@ fn get_markup_for_reminders_page_alteration(
             ),
         ))
     }
-    if !last_rem_page || !last_cron_rem_page {
+    if !last_rem_page {
         move_buttons.push(InlineKeyboardButton::new(
             "➡️",
             InlineKeyboardButtonKind::CallbackData(
